@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-version = '0.1.21'
+version = '0.1.22'
 release = 'barium'
 
 import os
@@ -83,6 +83,10 @@ class Runner(object):
             from lettuce.plugins import scenario_names as output
         elif verbosity is 3:
             from lettuce.plugins import shell_output as output
+        elif verbosity is 4:
+            from lettuce.plugins import colored_shell_output as output
+        elif verbosity is 5:
+            from lettuce.plugins import junit_output as output
         else:
             from lettuce.plugins import colored_shell_output as output
 
